@@ -7,15 +7,16 @@
 
     :copyright: (c) 2013-present by Abhinav Singh and contributors.
     :license: BSD, see LICENSE for more details.
+
+    .. spelling::
+
+       pre
 """
-from .acceptor import Acceptor
 from .pool import AcceptorPool
-from .work import Work
-from .threadless import Threadless
+from .acceptor import Acceptor
+
 
 __all__ = [
     'Acceptor',
     'AcceptorPool',
-    'Work',
-    'Threadless',
 ]
